<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="6">
            <el-form-item label="排查时间">
              <el-date-picker placeholder="请选择排查时间" clearable v-model="querys[0].value" type="date" value-format="yyyy-MM-dd">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="排查方式">
              <el-select clearable filterable v-model="querys[1].value" placeholder="请选择排查方式">
                <el-option v-for="item in pclbList" :key="item.value" :label="item.name" :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="发布状态">
              <el-select clearable filterable v-model="querys[2].value" placeholder="请选择发布状态">
                <el-option v-for="item in faztList" :key="item.value" :label="item.name" :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
        <!-- <el-form-item label="方案执行状态">
          <el-select
            clearable
            filterable
            v-model="querys[3].value"
            placeholder="请选择方案执行状态"
          >
            <el-option
              v-for="item in fazxztList"
              :key="item.value"
              :label="item.name"
              :value="item.value"
            >
            </el-option>
          </el-select>
        </el-form-item> -->
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" />
        <el-table-column fixed type="index" width="55" label="序号" />
        <el-table-column prop="schemeName" min-width="180" label="排查方案名称" show-overflow-tooltip />
        <el-table-column prop="checkDate" min-width="110" label="排查时间" show-overflow-tooltip />
        <el-table-column prop="checkTypeName" min-width="110" label="排查方式" show-overflow-tooltip />
        <el-table-column prop="workTargetContent" min-width="180" label="工作目标描述" show-overflow-tooltip />
        <!-- <el-table-column prop="startDate" min-width="110" label="开始时间" show-overflow-tooltip />
        <el-table-column prop="endDate" min-width="110" label="结束时间" show-overflow-tooltip /> -->
        <el-table-column prop="members" min-width="180" label="检查组织机构及成员描述" show-overflow-tooltip />
        <el-table-column prop="participant" min-width="180" label="检查区域和对象描述" show-overflow-tooltip />
        <el-table-column prop="sponsor" min-width="155" label="检查方式" show-overflow-tooltip />
        <el-table-column min-width="180" prop="participantCompany" label="检查要求" show-overflow-tooltip />
        <el-table-column min-width="180" prop="notes" label="注意事项描述" show-overflow-tooltip />
        <el-table-column prop="pubStateName" min-width="110" label="方案状态" show-overflow-tooltip />
        <!-- <el-table-column
          sortable
          prop="statusName"
          min-width="130"
          label="方案执行状态"
          show-overflow-tooltip
        /> -->
        <el-table-column fixed="right" prop="" min-width="80" label="操作" show-overflow-tooltip>
          <template slot-scope="scope">
            <el-button v-if="scope.row.pubState == 1" type="primary" plain @click="handleRelease(scope.row)">
              发布</el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <programDialog ref="formModal" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import programApi from '@/views/Manage/saftyDanger/api/programApi'
import programDialog from '@/views/Manage/saftyDanger/components/programDialog'
export default {
  name: 'nineLittlePlace',
  components: {
    programDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtSaftyDangerCheckscheme/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'check_Date_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'check_type_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'pub_state_',
          relation: 'AND',
          value: ''
        },
        // {
        //   group: 'main',
        //   operation: 'EQUAL',
        //   parentGroup: '',
        //   property: 'status_',
        //   relation: 'AND',
        //   value: ''
        // }
      ],
      StshowFormDias: false,
      types: [],
      sorter: [
        {
          direction: 'DESC',
          property: 'check_Date_'
        },
      ]
      // levels:[]
    }
  },
  created() {
    this.dwlxList = dictContracts.getDictItemsFromCache('zhgl-dwlx')
    this.pclbList = dictContracts.getDictItemsFromCache('pclb')
    this.pcztList = dictContracts.getDictItemsFromCache('pczt')
    this.fazxztList = dictContracts.getDictItemsFromCache('fazxzt')
    this.faztList = dictContracts.getDictItemsFromCache('fazt')
  },
  mounted() { },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      // this.querys[3].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam.sorter = this.sorter
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      // if (this.querys[3].value) {
      //   this.queryParam.querys.push(this.querys[3])
      // }
      programApi.loadCmgtSaftyDangerUnit(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.tableData.forEach(item => {
          this.pclbList.forEach(val => {
            if (item.checkType == val.value) {
              item['checkTypeName'] = val.name
            }
          })
          // 	item['emphasisTypeName'] = ''
          // 	this.zddwflList.forEach((val) => {
          // 		console.log(item.emphasisType);
          // 		if (item.emphasisType) {
          // 			item.emphasisType.split(',').forEach((e, ei) => {
          // 				if (e == val.value) {
          // 					if (ei + 1 < item.emphasisType.split(',').length) {
          // 						item['emphasisTypeName'] += val.name + ','
          // 					} else {
          // 						item['emphasisTypeName'] += val.name
          // 					}
          // 				}
          // 			})
          // 		}
          // 	})
          this.faztList.forEach(val => {
            if (item.pubState == val.value) {
              item['pubStateName'] = val.name
            }
          })
          this.fazxztList.forEach(val => {
            if (item.status == val.value) {
              item['statusName'] = val.name
            }
          })
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    handleRelease(val) {
      val.pubState = 2
      programApi.publishCmgtSaftyDangerUnit(val.id, res => {
        if (res.state) {
          this.$notify({
            type: 'success',
            message: '发布成功',
            duration: 2000
          })
          // this.$emit('loadData')
          this.loadData()
        } else {
          this.$message.warning(res.message)
        }
      })
    },
    // formartLevelName(row, column, cellValue, index){
    // 	var obj = this.levels.find(function(item) {
    // 		if (item.value === row.level) { //
    // 			return item
    // 		}
    // 	})
    // 	if (obj !== undefined) {
    // 		return obj.name;
    // 	} else {
    // 		return "";
    // 	}
    // },
    formartTyepName(row, column, cellValue, index) {
      var obj = this.types.find(function (item) {
        if (item.value === row.type) {
          //
          return item
        }
      })
      if (obj !== undefined) {
        return obj.name
      } else {
        return ''
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
